@@ -35,7 +35,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-popup-menu.h>
 
 #include "gedit-output-window.h"
 
@@ -69,51 +68,18 @@ enum
 	NUM_COLUMNS
 };
 
-static void gedit_output_window_class_init 	(GeditOutputWindowClass	*klass);
-static void gedit_output_window_init 		(GeditOutputWindow 	*output_window);
+
 static void gedit_output_window_finalize 	(GObject 	*object);
 static void gedit_output_window_destroy	 	(GtkObject 	*object);
 
-static GtkHBoxClass *parent_class = NULL;
-
-
-GType
-gedit_output_window_get_type (void)
-{
-	static GType output_window_type = 0;
-
-  	if (output_window_type == 0)
-    	{
-      		static const GTypeInfo our_info =
-      		{
-        		sizeof (GeditOutputWindowClass),
-        		NULL,		/* base_init */
-        		NULL,		/* base_finalize */
-        		(GClassInitFunc) gedit_output_window_class_init,
-        		NULL,           /* class_finalize */
-        		NULL,           /* class_data */
-        		sizeof (GeditOutputWindow),
-        		0,              /* n_preallocs */
-        		(GInstanceInitFunc) gedit_output_window_init
-      		};
-
-      		output_window_type = g_type_register_static (GTK_TYPE_HBOX,
-                				    "GeditOutputWindow",
-                                       	 	    &our_info,
-                                       		    0);
-    	}
-
-	return output_window_type;
-}
+G_DEFINE_TYPE(GeditOutputWindow, gedit_output_window, GTK_TYPE_HBOX)
 
 static void
 gedit_output_window_class_init (GeditOutputWindowClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  	parent_class = g_type_class_peek_parent (klass);
-
-  	object_class->finalize = gedit_output_window_finalize;
+   	object_class->finalize = gedit_output_window_finalize;
 	
 	GTK_OBJECT_CLASS (klass)->destroy = gedit_output_window_destroy;
 
@@ -283,6 +249,35 @@ create_popup_menu (GeditOutputWindow  *output_window)
 	return menu;
 }
 
+static gint
+my_popup_handler (GtkWidget *widget, GdkEvent *event)
+{
+  GtkMenu *menu;
+  GdkEventButton *event_button;
+
+  g_return_val_if_fail (widget != NULL, FALSE);
+  g_return_val_if_fail (GTK_IS_MENU (widget), FALSE);
+  g_return_val_if_fail (event != NULL, FALSE);
+
+  /* The "widget" is the menu that was supplied when 
+   * g_signal_connect_swapped() was called.
+   */
+  menu = GTK_MENU (widget);
+
+  if (event->type == GDK_BUTTON_PRESS)
+    {
+      event_button = (GdkEventButton *) event;
+      if (event_button->button == 3)
+	{
+	  gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 
+			  event_button->button, event_button->time);
+	  return TRUE;
+	}
+    }
+
+  return FALSE;
+}
+
 static void
 gedit_output_window_treeview_selection_changed (GtkTreeSelection *selection, 
 						GeditOutputWindow  *output_window)
@@ -306,6 +301,17 @@ gedit_output_window_treeview_selection_changed (GtkTreeSelection *selection,
 	}
 }
 
+static void
+gedit_output_window_format_button (GtkButton* button, gint w, gint h)
+{
+	GtkRcStyle* rc = gtk_widget_get_modifier_style (GTK_WIDGET (button));
+	rc->xthickness = 0;
+	rc->ythickness = 0;
+        gtk_widget_modify_style (GTK_WIDGET (button), rc);
+	gtk_button_set_relief (button, GTK_RELIEF_NONE);
+	gtk_button_set_focus_on_click (button, FALSE);
+}
+
 static void 
 gedit_output_window_init (GeditOutputWindow  *output_window)
 {
@@ -334,7 +340,7 @@ gedit_output_window_init (GeditOutputWindow  *output_window)
 	settings = gtk_widget_get_settings (GTK_WIDGET (output_window));
 
 	gtk_icon_size_lookup_for_settings (settings,
-					   GTK_ICON_SIZE_SMALL_TOOLBAR,
+					   GTK_ICON_SIZE_MENU,
 					   &w, &h);
 
 	vbox1 = gtk_vbox_new (FALSE, 2);
@@ -343,16 +349,15 @@ gedit_output_window_init (GeditOutputWindow  *output_window)
 	/* Create the close button */
 	output_window->priv->close_button = gtk_button_new ();
 	gtk_box_pack_start (GTK_BOX (vbox1), output_window->priv->close_button, FALSE, FALSE, 0);
-	gtk_widget_set_size_request (output_window->priv->close_button, w + 2, h + 2);
 
 	gtk_tooltips_set_tip (output_window->priv->tooltips, 
 			      output_window->priv->close_button, 
 			      _("Close the output window"), 
 			      NULL);
 
-	gtk_button_set_relief (GTK_BUTTON (output_window->priv->close_button), GTK_RELIEF_NONE);
+	gedit_output_window_format_button (GTK_BUTTON (output_window->priv->close_button), w, h);
 
-	image = gtk_image_new_from_stock ("gtk-close", GTK_ICON_SIZE_SMALL_TOOLBAR);
+	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
   	gtk_container_add (GTK_CONTAINER (output_window->priv->close_button), image);
 	
 	g_signal_connect (output_window->priv->close_button, 
@@ -381,16 +386,15 @@ gedit_output_window_init (GeditOutputWindow  *output_window)
 	/* Create the copy button */
 	output_window->priv->copy_button = gtk_button_new ();
 	gtk_box_pack_start (GTK_BOX (vbox2), output_window->priv->copy_button, FALSE, FALSE, 0);
-  	gtk_widget_set_size_request (output_window->priv->copy_button, w + 2, h + 2);
 
 	gtk_tooltips_set_tip (output_window->priv->tooltips, 
 			      output_window->priv->copy_button, 
 			      _("Copy selected lines"), 
 			      NULL);
 
-	gtk_button_set_relief (GTK_BUTTON (output_window->priv->copy_button), GTK_RELIEF_NONE);
+	gedit_output_window_format_button (GTK_BUTTON (output_window->priv->copy_button), w, h);
 
-	image = gtk_image_new_from_stock ("gtk-copy", GTK_ICON_SIZE_SMALL_TOOLBAR);
+	image = gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU);
   	gtk_container_add (GTK_CONTAINER (output_window->priv->copy_button), image);
 
 	g_signal_connect (output_window->priv->copy_button, 
@@ -401,16 +405,15 @@ gedit_output_window_init (GeditOutputWindow  *output_window)
 	/* Create the clear button */
 	output_window->priv->clear_button = gtk_button_new ();
 	gtk_box_pack_start (GTK_BOX (vbox2), output_window->priv->clear_button, FALSE, FALSE, 0);
-	gtk_widget_set_size_request (output_window->priv->clear_button, w + 2, h + 2);
 	
 	gtk_tooltips_set_tip (output_window->priv->tooltips, 
 			      output_window->priv->clear_button, 
 			      _("Clear the output window"), 
 			      NULL);
 	
-	gtk_button_set_relief (GTK_BUTTON (output_window->priv->clear_button), GTK_RELIEF_NONE);
+	gedit_output_window_format_button (GTK_BUTTON (output_window->priv->clear_button), w, h);
 
-	image = gtk_image_new_from_stock ("gtk-clear", GTK_ICON_SIZE_SMALL_TOOLBAR);
+	image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU);
 	gtk_container_add (GTK_CONTAINER (output_window->priv->clear_button), image);
 
 	g_signal_connect (output_window->priv->clear_button, 
@@ -481,7 +484,11 @@ gedit_output_window_init (GeditOutputWindow  *output_window)
 
 	popup_menu = create_popup_menu (output_window);
 		
-	gnome_popup_menu_attach (popup_menu, output_window->priv->treeview, NULL);
+	gtk_menu_attach_to_widget(GTK_MENU(popup_menu), output_window->priv->treeview, NULL);
+	
+	g_signal_connect_swapped (output_window->priv->treeview, "button_press_event",	G_CALLBACK (my_popup_handler), popup_menu);
+	
+			  
 }
 
 static void 
@@ -498,13 +505,13 @@ gedit_output_window_finalize (GObject *object)
 		g_free (ow->priv);
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gedit_output_window_parent_class)->finalize (object);
 }
 
 static void 
 gedit_output_window_destroy (GtkObject *object)
 {
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	GTK_OBJECT_CLASS (gedit_output_window_parent_class)->destroy (object);
 }
 
 GtkWidget *
